Crate kcr_sloth_slok_dev

Crate kcr_sloth_slok_dev 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the sloth.slok.dev group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

sloth.slok.dev/v1

  • PrometheusServiceLevel

Modules

v1